``ExposoGraph.exporter``
========================

Export and parse the knowledge graph as interactive HTML, Plotly HTML, JS, JSON, and GEXF.

All engine-based export helpers accept a ``visibility`` argument so you can
export:

- the full graph (``all``)
- validated content only (``validated_only``)
- exploratory content only (``exploratory_only``)

.. automodule:: ExposoGraph.exporter
   :members:
   :undoc-members:
